==> difftastic-0.58.0.tar.gz: difftastic-0.58.0/vendored_parsers/tree-sitter-clojure/doc/credits.md <==
## Credits

Many people were directly and indirectly involved in bringing about tree-sitter-clojure.  I may have missed some people below, please let me know if I have.  Thanks to all!

* Aerijo - Guide to your first Tree-sitter grammar
* ahlinc - tree-sitter work
* alehatsman - nvim-treesitter and related discussion
* alexmiller - clojure-related inquiries and docs
* andrewchambers - discussion
* bfredl - neovim and tree-sitter work
* borkdude - analyze-reify, babashka, clj-kondo, edamame, and more
* carocad - parcera and discussions
* cgrand - ClojureDart and related reader explanation
* clojars - including everyone who has uploaded there
* CoenraadS - Bracket-Pair-Colorizer-2
* dannyfreeman - grammar.js enhancements and fixes, clojure-ts-mode and discussions
* EvegeniyPeshkov - syntax-highlighter
* georgewfraser - vscode-tree-sitter
* gfredericks - test.check, generators, and discussions
* GrayJack - discussions and tree-sitter-janet
* hitode909 - vscode-perl-outline
* iarenaza - discussions
* IGJoshua - ClojureCLR investigations
* jafingerhut - clojure-related inquiries and haironfire research
* jeff-hykin - tree-sitter and VSCode related
* kolja - nrepl-alliance and tree-sitter question concerning Clojure on StackOverflow
* lread - rewrite-cljc and discussions
* mauricioszabo - clover and repl-tooling
* maxbrunsfeld - tree-sitter and related
* monnier - emacs-tree-sitter related
* NoahTheDuke - discussion and suggestions
* nwjsmith - tree-sitter upgrade
* oakmac - tree-sitter-clojure.oakmac, conj 2018 unsession, advice, etc.
* p00f - nvim-ts-rainbow
* pedrorgirardi - discussions, vscode and tree-sitter-clojure bits
* PEZ - calva, vscode tips, and general discussion
* pyrmont - review, error-spotting, fix, and discussions
* rewinfrey - helpful bits from tree-sitter-haskell
* richhickey - clojure, etc.
* Saikyun - discussions
* seancorfield - clojure-related inquiries
* SergeevPavel - tree-sitter-clojure.SergeevPavel (fork of tree-sitter-clojure.Tavistock with further work)
* SevereOverfl0w - tree-sitter and vim info
* shackra - tree-sitter-query.el
* SignSpice - discussion
* snoe - discussions
* Tavistock - tree-sitter-clojure.Tavistock
* th0rex - emacs-tree-sitter related
* theHamsta - neovim, nvim-treesitter, tree-sitter-commonlisp
* tobias - clojars work
* tonsky - sublime-clojure work with test data, clojure north talk, alabaster theme
* ubolonton - emacs-tree-sitter
* vigoux - nvim-treesitter and related
* Wilfred - difftastic, bug reporting, and discussion

==> difftastic-0.65.0.tar.gz: difftastic-0.65.0/vendored_parsers/tree-sitter-clojure/doc/credits.md <==
## Credits

Many people were directly and indirectly involved in bringing about tree-sitter-clojure.  I may have missed some people below, please let me know if I have.  Thanks to all!

* Aerijo - Guide to your first Tree-sitter grammar
* ahlinc - tree-sitter work
* alehatsman - nvim-treesitter and related discussion
* alexmiller - clojure-related inquiries and docs
* andrewchambers - discussion
* bbatsov - discussions and clojure-ts-mode
* bfredl - neovim and tree-sitter work
* borkdude - analyze-reify, babashka, clj-kondo, edamame, and more
* carocad - parcera and discussions
* cgrand - ClojureDart and related reader explanation
* clojars - including everyone who has uploaded there
* CoenraadS - Bracket-Pair-Colorizer-2
* dannyfreeman - grammar.js enhancements and fixes, clojure-ts-mode and discussions
* dmiller - ClojureCLR consultation
* EvegeniyPeshkov - syntax-highlighter
* georgewfraser - vscode-tree-sitter
* gfredericks - test.check, generators, and discussions
* GrayJack - discussions and tree-sitter-janet
* hitode909 - vscode-perl-outline
* iarenaza - discussions
* IGJoshua - ClojureCLR investigations
* jafingerhut - clojure-related inquiries and haironfire research
* jeff-hykin - tree-sitter and VSCode related
* kolja - nrepl-alliance and tree-sitter question concerning Clojure on StackOverflow
* lread - rewrite-cljc and discussions
* mauricioszabo - clover and repl-tooling
* maxbrunsfeld - tree-sitter and related
* monnier - emacs-tree-sitter related
* NoahTheDuke - discussion and suggestions
* nwjsmith - tree-sitter upgrade
* oakmac - tree-sitter-clojure.oakmac, conj 2018 unsession, advice, etc.
* p00f - nvim-ts-rainbow
* pedrorgirardi - discussions, vscode and tree-sitter-clojure bits
* PEZ - calva, vscode tips, and general discussion
* phronmophobic - dewey, discussion, and repository data
* pyrmont - review, error-spotting, fix, and discussions
* rewinfrey - helpful bits from tree-sitter-haskell
* richhickey - clojure, etc.
* rrudakov - discussions and clojure-ts-mode
* Saikyun - discussions
* seancorfield - clojure-related inquiries
* SergeevPavel - tree-sitter-clojure.SergeevPavel (fork of tree-sitter-clojure.Tavistock with further work)
* SevereOverfl0w - tree-sitter and vim info
* shackra - tree-sitter-query.el
* SignSpice - discussion
* snoe - discussions
* Tavistock - tree-sitter-clojure.Tavistock
* th0rex - emacs-tree-sitter related
* theHamsta - neovim, nvim-treesitter, tree-sitter-commonlisp
* tobias - clojars work
* tonsky - sublime-clojure work with test data, clojure north talk, alabaster theme
* ubolonton - emacs-tree-sitter
* vigoux - nvim-treesitter and related
* Wilfred - difftastic, bug reporting, and discussion
